Package: ContourFunctions
Type: Package
Title: Create Contour Plots from Data or a Function
Version: 0.1.2
Authors@R: person("Collin", "Erickson", 
  email = "collinberickson@gmail.com",
  role = c("aut", "cre"))
Description: Provides functions for making contour plots.
  The contour plot can be created from grid data, a function,
  or a data set. If non-grid data is given, then a Gaussian
  process is fit to the data and used to create the contour plot.
License: GPL-3
RoxygenNote: 7.3.1
Imports: rlang
Depends: ggplot2, lhs, rmarkdown
Suggests: covr, knitr, laGP, locfit, mgcv, mlegp, testthat
VignetteBuilder: knitr
URL: https://github.com/CollinErickson/ContourFunctions
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2024-09-09 23:52:39 UTC; colli
Author: Collin Erickson [aut, cre]
Maintainer: Collin Erickson <collinberickson@gmail.com>
Repository: CRAN
Date/Publication: 2024-09-10 15:00:12 UTC
Built: R 4.6.0; ; 2026-04-28 14:05:13 UTC; unix
