# Generated by roxygen2: do not edit by hand

export(cf)
export(cf_4dim)
export(cf_data)
export(cf_func)
export(cf_grid)
export(cf_highdim)
export(cm.colors.strong)
export(csa)
export(eval_over_grid_with_batch)
export(gcf)
export(gcf_data)
export(gcf_func)
export(gcf_grid)
export(multicolor.title)
export(text_plot)
importFrom(ggplot2,ggplot)
importFrom(grDevices,cm.colors)
importFrom(graphics,.filled.contour)
importFrom(graphics,Axis)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,close.screen)
importFrom(graphics,contour)
importFrom(graphics,layout)
importFrom(graphics,lcm)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,plot.new)
importFrom(graphics,plot.window)
importFrom(graphics,points)
importFrom(graphics,rect)
importFrom(graphics,screen)
importFrom(graphics,split.screen)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(lhs,randomLHS)
importFrom(rlang,.data)
importFrom(rmarkdown,html_vignette)
importFrom(stats,lm)
importFrom(stats,predict)
importFrom(utils,capture.output)
