I added new functions and new functionality.

## Test environments
* local Windows 7 install, R 3.6.0
* ubuntu 14.04 (on travis-ci), R 3.6.0
* win-builder (devel and release)

## R CMD check results

0 errors | 0 warnings | 0 notes

## Reverse dependencies

The only reverse dependency is another package of mine,
and it doesn't affect it.
